@@ -5,6 +5,7 @@
 
 #include "common.h"
 #include "tls.h"
+#include "log.h"
 
 typedef enum {
     PROBE_NEXT,  /* Enough data, probe failed -- it's some other protocol */
@@ -13,7 +14,7 @@ typedef enum {
 } probe_result;
 
 struct sslhcfg_protocols_item;
-typedef int T_PROBE(const char*, int, struct sslhcfg_protocols_item*);
+typedef int T_PROBE(const char*, ssize_t, struct sslhcfg_protocols_item*);
 
 struct protocol_probe_desc {
     const char* name;
@@ -47,6 +48,13 @@ void set_protocol_list(struct sslhcfg_protocols_item*);
  */
 int probe_client_protocol(struct connection *cnx);
 
+/* Probe on a buffer */
+int probe_buffer(char* buf, int len,
+                 struct sslhcfg_protocols_item** proto_in,
+                 int proto_len,
+                 struct sslhcfg_protocols_item** proto_out
+                 );
+
 /* set the protocol to connect to in case of timeout */
 void set_ontimeout(const char* name);
 
@@ -56,6 +64,6 @@ void set_ontimeout(const char* name);
  */
 struct sslhcfg_protocols_item* timeout_protocol(void);
 
-void hexdump(const char*, unsigned int);
+void hexdump(msg_info, const char*, unsigned int);
 
 #endif
